@@ -21,7 +21,7 @@ READ_ONCE_LENGTH = 65536
 CONTENT_LENGTH_HEADER = 'Content-Length'
 CONTENT_TYPE_HEADER = 'Content-Type'
 CONTENT_MD5_HEADER = 'Content-MD5'
-CACHE_CONTROL_HEADER = 'Cache-Control'
+CACHE_CONTROL_HEADER = 'Cache-Control'  # type: str
 CONTENT_DISPOSITION_HEADER = 'Content-Disposition'
 CONTENT_ENCODING_HEADER = 'Content-Encoding'
 CONTENT_LANGUAGE_HEADER = 'Content-Language'
@@ -96,7 +96,7 @@ DEFAULT_TASK_INTTERVAL = 100
 DEFAULT_TASK_NUM = 8
 DEFAULT_TASK_QUEUE_SIZE = 20000
 
-OBS_SDK_VERSION = '3.23.12'
+OBS_SDK_VERSION = '3.24.3'
 
 V2_META_HEADER_PREFIX = 'x-amz-meta-'
 V2_HEADER_PREFIX = 'x-amz-'
